@@ -138,6 +138,10 @@ window.cockpit_po = {
   null,
   "Administrando con la consola Web de Cockpit"
  ],
+ "Administrative access": [
+  null,
+  "Acceso administrativo"
+ ],
  "Advanced TCA": [
   null,
   "TCA avanzado"
@@ -154,6 +158,10 @@ window.cockpit_po = {
   null,
   "Documentación de los roles de Ansible"
  ],
+ "Authenticate": [
+  null,
+  "Autenticar"
+ ],
  "Authentication": [
   null,
   "Autenticación"
@@ -374,6 +382,10 @@ window.cockpit_po = {
   null,
   "PC integrado"
  ],
+ "Error during initialization": [
+  null,
+  "Error durante la inicialización"
+ ],
  "Excellent password": [
   null,
   "Contraseña excelente"
@@ -382,6 +394,10 @@ window.cockpit_po = {
   null,
   "Chasis de expansión"
  ],
+ "Failed": [
+  null,
+  "Falló"
+ ],
  "Failed to change password": [
   null,
   "Error al cambiar contraseña"
@@ -498,6 +514,18 @@ window.cockpit_po = {
   null,
   "Aprenda más"
  ],
+ "Limit access": [
+  null,
+  "Limitar acceso"
+ ],
+ "Limited access": [
+  null,
+  "Acceso limitado"
+ ],
+ "Limited access mode restricts administrative privileges. Some parts of the web console will have reduced functionality.": [
+  null,
+  "El modo de acceso limitado restringe los privilegios administrativos. Algunas partes de la consola web tendrán funcionalidad reducida."
+ ],
  "Loading system modifications...": [
   null,
   "Cargando modificaciones del sistema..."
@@ -558,6 +586,10 @@ window.cockpit_po = {
   null,
   "Mensaje para usuarios activos"
  ],
+ "Method": [
+  null,
+  "Método"
+ ],
  "Mini PC": [
   null,
   "Mini PC"
@@ -594,6 +626,10 @@ window.cockpit_po = {
   null,
   "Sin retardo"
  ],
+ "No methods to gain administrative access are available (sudo -A, pkexec).": [
+  null,
+  "No hay métodos disponibles para obtener acceso administrativo (sudo -A, pkexec)."
+ ],
  "No results found": [
   null,
   "No se encontraron resultados"
@@ -702,6 +738,10 @@ window.cockpit_po = {
   null,
   "Caja de pizza"
  ],
+ "Please authenticate to gain administrative access": [
+  null,
+  "Autentíquese para obtener acceso administrativo"
+ ],
  "Please enable JavaScript to use the Web Console.": [
   null,
   "Por favor, habilite JavaScript para usar la consola Web."
@@ -718,6 +758,10 @@ window.cockpit_po = {
   null,
   "Presente"
  ],
+ "Problem becoming administrator": [
+  null,
+  "Problema al cambiar a administrador"
+ ],
  "Prompting via ssh-add timed out": [
   null,
   "Ha expirado el tiempo de ssh-add"
@@ -862,6 +906,14 @@ window.cockpit_po = {
   null,
   "Subportátil"
  ],
+ "Switch to administrative access": [
+  null,
+  "Cambiar a acceso administrativo"
+ ],
+ "Switch to limited access": [
+  null,
+  "Pasar a acceso limitado"
+ ],
  "Synchronized": [
   null,
   "Sincronizado"
@@ -998,6 +1050,10 @@ window.cockpit_po = {
   null,
   "Intentando sincronizar con $0"
  ],
+ "Turn on administrative access": [
+  null,
+  "Habilitar el acceso administrativo"
+ ],
  "Unable to connect to that address": [
   null,
   "No se pudo realizar una conexión con esa dirección"
@@ -1074,10 +1130,18 @@ window.cockpit_po = {
   null,
   "Se está conectando con $0 por primera vez."
  ],
+ "You now have administrative access.": [
+  null,
+  "Ahora tienes acceso administrativo."
+ ],
  "Your browser does not allow paste from the context menu. You can use Shift+Insert.": [
   null,
   "Tu navegador no admite pegar desde el menú contextual. Puedes usar Shift+Insert."
  ],
+ "Your browser will remember your access level across sessions.": [
+  null,
+  "Su navegador recordará su nivel de acceso entre sesiones."
+ ],
  "Your session has been terminated.": [
   null,
   "Su sesión se ha terminado."
