@@ -382,6 +382,10 @@ window.cockpit_po = {
   null,
   "PC integrato"
  ],
+ "Error during initialization": [
+  null,
+  ""
+ ],
  "Excellent password": [
   null,
   "Password eccellente"
@@ -390,6 +394,10 @@ window.cockpit_po = {
   null,
   "Chassis di espansione"
  ],
+ "Failed": [
+  null,
+  "Fallito"
+ ],
  "Failed to change password": [
   null,
   "Impossibile cambiare la password"
