@@ -106,7 +106,7 @@ window.cockpit_po = {
  ],
  "A new SSH key at $0 will be created for $1 on $2 and it will be added to the $3 file of $4 on $5.": [
   null,
-  "$0 で新しい SSH キーが $2 の $1 用に作成され、$5 上の $3 の $3 ファイルに追加されました。"
+  "$0 で新しい SSH キーが $2 の $1 用に作成され、$5 上の $4 の $3 ファイルに追加されました。"
  ],
  "Absent": [
   null,
@@ -376,6 +376,10 @@ window.cockpit_po = {
   null,
   "組み込み PC"
  ],
+ "Error during initialization": [
+  null,
+  ""
+ ],
  "Excellent password": [
   null,
   "優れたパスワード"
@@ -384,6 +388,10 @@ window.cockpit_po = {
   null,
   "拡張シャーシ"
  ],
+ "Failed": [
+  null,
+  "失敗"
+ ],
  "Failed to change password": [
   null,
   "パスワードの変更に失敗しました"
