@@ -236,7 +236,7 @@ window.cockpit_po = {
  ],
  "Checking installed software": [
   null,
-  "Verificando o software instalado"
+  "Verificando software instalado"
  ],
  "Clear input value": [
   null,
@@ -382,6 +382,10 @@ window.cockpit_po = {
   null,
   "PC integrado"
  ],
+ "Error during initialization": [
+  null,
+  "Erro durante inicialização"
+ ],
  "Excellent password": [
   null,
   "Senha excelente"
@@ -390,6 +394,10 @@ window.cockpit_po = {
   null,
   "Chassi de Expansão"
  ],
+ "Failed": [
+  null,
+  "Falhou"
+ ],
  "Failed to change password": [
   null,
   "Falha ao mudar senha"
@@ -620,7 +628,7 @@ window.cockpit_po = {
  ],
  "No methods to gain administrative access are available (sudo -A, pkexec).": [
   null,
-  ""
+  "Não existem métodos disponíveis para obter acesso administrativo (sudo -A, pkexec)."
  ],
  "No results found": [
   null,
@@ -1104,7 +1112,7 @@ window.cockpit_po = {
  ],
  "Waiting for other software management operations to finish": [
   null,
-  "Aguardando que outras operações de gerenciamento de software terminem"
+  "Aguardando a conclusão de outras operações de gerenciamento de software"
  ],
  "Weak password": [
   null,
