@@ -388,6 +388,10 @@ window.cockpit_po = {
   null,
   "Вбудований ПК"
  ],
+ "Error during initialization": [
+  null,
+  "Помилка під час ініціалізації"
+ ],
  "Excellent password": [
   null,
   "Чудовий пароль"
@@ -396,6 +400,10 @@ window.cockpit_po = {
   null,
   "Апаратний блок розширення"
  ],
+ "Failed": [
+  null,
+  "Помилка"
+ ],
  "Failed to change password": [
   null,
   "Не вдалося змінити пароль"
